==> haskell-here-1.2.13-52-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: here
version: 1.2.13
id: here-1.2.13-2Abkl4uZcNP70TzIkvpL6m
key: here-1.2.13-2Abkl4uZcNP70TzIkvpL6m
license: BSD-3-Clause
copyright: ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer: t@tmh.cc
author: Taylor M. Hedberg
homepage: https://github.com/tmhedberg/here
synopsis: Here docs & interpolated strings via quasiquotation
description:
    Here docs & interpolated strings via quasiquotation
category: Data
abi: bd0e35a1c495e8a9a4e2dbd39780bd99
exposed: True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated
hidden-modules: Data.String.Here.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/here-1.2.13
library-dirs: /usr/lib/ghc-8.6.3/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/here-1.2.13
hs-libraries: HShere-1.2.13-2Abkl4uZcNP70TzIkvpL6m
depends:
    base-4.12.0.0 haskell-src-meta-0.8.0.3-4wszG05U4K8AvYSAywB7K6
    mtl-2.2.2 parsec-3.1.13.0 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-here/html/here.haddock
haddock-html: /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-here-1.2.13-54-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: here
version: 1.2.13
id: here-1.2.13-9DltI7NGKon6lddX8ZAFsy
key: here-1.2.13-9DltI7NGKon6lddX8ZAFsy
license: BSD-3-Clause
copyright: ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer: t@tmh.cc
author: Taylor M. Hedberg
homepage: https://github.com/tmhedberg/here
synopsis: Here docs & interpolated strings via quasiquotation
description:
    Here docs & interpolated strings via quasiquotation
category: Data
abi: 9060fab163894976948973c93a09c0d5
exposed: True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated
hidden-modules: Data.String.Here.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/here-1.2.13
library-dirs: /usr/lib/ghc-8.6.3/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/here-1.2.13
hs-libraries: HShere-1.2.13-9DltI7NGKon6lddX8ZAFsy
depends:
    base-4.12.0.0 haskell-src-meta-0.8.1-GZqJA60lLk6FTDtlVp0y5l
    mtl-2.2.2 parsec-3.1.13.0 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-here/html/here.haddock
haddock-html: /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
